==> cenote_0.8.4_20071018.zip: cenote/setup/index4.php <==
<?php
if(file_exists("../configuration.php")){
	header("Location: ./index.php");
}
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<title>CENOTE SETUP TOOL(DATABASE SETTING)</title>
<style type="text/css">
<!--
body {
	margin-left: 0px;
	margin-top: 0px;
	margin-right: 0px;
	margin-bottom: 0px;
}
.style1 {
	font-size: 24px;
	font-style: italic;
	text-align: center;
}
.style2 {font-size: 14px; font-style: bold; text-align: left;}

.red {color: #FF0000}

-->
</style>
</head>
<?php
session_name("CENOTE_SETUP");
session_cache_limiter('private, must-revalidate');
session_start();

$mes = "";

$db_type 	= isset($_POST['db_type']) ? $_POST['db_type'] : "";
$db_name	= isset($_POST['db_name']) ? $_POST['db_name'] : "";
$db_port	= isset($_POST['db_port']) ? $_POST['db_port'] : "";
$db_host 	= isset($_POST['db_host']) ? $_POST['db_host'] : "localhost";
$db_user 	= isset($_POST['db_user']) ? $_POST['db_user'] : "";
$db_passwd 	= isset($_POST['db_passwd']) ? $_POST['db_passwd'] : "";



if($db_type != "" && $db_name != "" && $db_port != "" && $db_host != "" && $db_user != ""&& $db_passwd){
	$_SESSION['db_type'] = $db_type;
	$_SESSION['db_name'] = $db_name;
	$_SESSION['db_port'] = $db_port;
	$_SESSION['db_host'] = $db_host;
	$_SESSION['db_user'] = $db_user;
	$_SESSION['db_passwd'] = $db_passwd;


	if($db_type == "pgsql"){
		$DSN = $db_type;
		$DSN .= ":host=".$db_host;
		$DSN .= " port=".$db_port;
		$DSN .= " dbname=".$db_name;
		$DSN .= " user=".$db_user;
		$DSN .= " password=".$db_passwd;

		try {
			$dbh = new PDO($DSN);

			// カラム名を小文字で取得する
			$dbh->setAttribute(PDO::ATTR_CASE, PDO::CASE_LOWER);

			// エラー時にExceptionをthrowさせる
			$dbh->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
		}
		catch (PDOException $e) {
			$mes .= 'データベースに接続できませんでした';
		}

		if($mes == ""){
			$chk = true;
			$jump = "index5.php";
		} else {
			$chk = false;
			$jump = "index4.php";
		}
	}
	if($db_type == "mysql"){
		
		$DSN = $db_type;
		$DSN .= ":dbname=".$db_name;
		$DSN .= ";port=".$db_port;
		$DSN .= ";host=".$db_host;

		try {
			$dbh = new PDO($DSN, $db_user, $db_passwd);

			// カラム名を小文字で取得する
			$dbh->setAttribute(PDO::ATTR_CASE, PDO::CASE_LOWER);

			// エラー時にExceptionをthrowさせる
			$dbh->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
		}
		catch (PDOException $e) {
			$mes .= 'データベースに接続できませんでした';
		}

		if($mes == ""){
			$chk = true;
			$jump = "index5.php";
		} else {
			$chk = false;
			$jump = "index4.php";
		}
	}
} else {

	if($db_type == ""){
		$mes .=  "データベースタイプが未入力です<br >";
	}
	if($db_name == ""){
		$mes .=  "データベース名が未入力です<br >";
	}
	if($db_port == ""){
		$mes .=  "データベース接続ポート番号が未入力です<br >";
	}
	if($db_host == ""){
		$mes .=  "データベースホスト名が未入力です<br >";
	}
	if($db_user == ""){
		$mes .=  "データベース接続ユーザー名が未入力です<br >";
	}
	if($db_passwd == ""){
		$mes .=  "データベース接続パスワードがが未入力です<br >";
	}




	$chk = false;
	$jump = "index4.php";
}

?>
<body>
<form id="setup" name="setup" method="post" action="<?php echo $jump ?>">
<table width="100%" border="0">
	<tr>
		<td height="362" valign="top">
		<div align="center">
		<p><img src="./images/cenote_logo.png" width="350" height="100" /></p>
		<p class="style1">～SETUP TOOL～</p>
		<p class="style1">３．データベース作成</p>

		<table>
		<?php
		if(isset($_POST['Submit'])){
			if($_POST['Submit'] == "確認"){
				if($mes != ""){
					echo "<tr>";
					echo "<td colspan = \"2\"><span class=\"red\">";
					echo $mes;
					echo "</span></td>";
					echo "</tr>";
				}
			}
		}
		?>
		<?php
		if( $chk ){
			echo "<tr>
          		<td class=\"style2\">データベースタイプ</td>
          		<td class=\"style2\">$db_type</td>
        		</tr>
       		 <tr>
        		<td class=\"style2\">データベース名</td>
        		<td class=\"style2\">$db_name</td>
       		 </tr>
       		 <tr>
        		<td class=\"style2\">接続ポート番号</td>
        		<td class=\"style2\">$db_port</td>
       		 </tr>
       		 <tr>
          		<td class=\"style2\">DBホスト名</td>
          		<td class=\"style2\">$db_host</td>
        		</tr>
       		 <tr>
          		<td class=\"style2\">接続ユーザー名</td>
          		<td class=\"style2\">$db_user</td>
        	 </tr>
        	 <tr>
          		<td class=\"style2\">接続パスワード</td>
          		<td class=\"style2\">$db_passwd</td>
        	</tr>
        	<tr>";
			echo '<td colspan="2"><div align="center"><input name="Submit" type="submit" id="Submit" value="次へ" /></div>';
		} else {
			echo "<tr>
		          <td class=\"style2\">データベースタイプ</td>
					<td class=\"style2\">	
					<select name=\"db_type\">
  						<option value=\"pgsql\" selected=\"selected\">PostgreSQL</option>
  						<option value=\"mysql\">MySQL</option>
					</select>
					</td>
		        </tr>
		        <tr>
		          <td class=\"style2\">データベース名</td>
		          <td class=\"style2\"><input name=\"db_name\" type=\"text\" id=\"db_name\" value=\"$db_name\" /></td>
		        </tr>
		        <tr>
		          <td class=\"style2\">接続ポート番号</td>
		          <td class=\"style2\"><input name=\"db_port\" type=\"text\" id=\"db_port\" value=\"$db_port\" />　標準はPostgreSQL=5432　MySQL=3306です</td>
		        </tr>
		        <tr>
		          <td class=\"style2\">DBホスト名</td>
		          <td class=\"style2\"><input name=\"db_host\" type=\"text\" id=\"db_host\" value=\"$db_host\" /></td>
		        </tr>
		        <tr>
		          <td class=\"style2\">接続ユーザー名</td>
		          <td class=\"style2\"><input name=\"db_user\" type=\"text\" id=\"db_user\" value=\"$db_user\" /></td>
		        </tr>
		        <tr>
		          <td class=\"style2\">接続パスワード</td>
		          <td class=\"style2\"><input name=\"db_passwd\" type=\"text\" id=\"db_passwd\" value=\"$db_passwd\" /></td>
		        </tr>
		        <tr>";
			echo '<td colspan="2"><div align="center"><input name="Submit" type="submit" id="Submit" value="確認" /></div>';
		}
		?>
			</td>
			</tr>
			<p>&nbsp;</p>
			</div>
			</td>
			</tr>
		</table>
		</form>

</body>
</html>

==> cenote_0.9.3_20071026.zip: cenote/setup/index4.php <==
<?php
if(file_exists("../configuration.php")){
	header("Location: ./index.php");
}
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<title>CENOTE SETUP TOOL(DATABASE SETTING)</title>
<style type="text/css">
<!--
body {
	margin-left: 0px;
	margin-top: 0px;
	margin-right: 0px;
	margin-bottom: 0px;
}
.style1 {
	font-size: 24px;
	font-style: italic;
	text-align: center;
}
.style2 {font-size: 14px; font-style: bold; text-align: left;}

.red {color: #FF0000}

table.con {
	border-style: solid;
    border-width: 1px;
    border-color: #666;
}

th.con {
	width:100%;
	height:21px;
	color: #EEE;
	background-color: #CCC;
	border-width: 1px;
	margin: 0px;
	padding: 0px;
	text-align:left;
	font-size: 12px;
	font-weight: bold;
}
td.con {
	height:25px;
	font-size: 12px;
	font-style: normal;
	margin: 0px;
	background-color: #DDD;
	border-width: 1px;
	padding: 1px;
	color: #000;
}
-->
</style>
</head>
<?php
session_name("CENOTE_SETUP");
session_cache_limiter('private, must-revalidate');
session_start();

$mes = "";

$db_type 	= isset($_POST['db_type']) ? $_POST['db_type'] : "";
$db_name	= isset($_POST['db_name']) ? $_POST['db_name'] : "";
$db_port	= isset($_POST['db_port']) ? $_POST['db_port'] : "";
$db_host 	= isset($_POST['db_host']) ? $_POST['db_host'] : "localhost";
$db_user 	= isset($_POST['db_user']) ? $_POST['db_user'] : "";
$db_passwd 	= isset($_POST['db_passwd']) ? $_POST['db_passwd'] : "";



if($db_type != "" && $db_name != "" && $db_port != "" && $db_host != "" && $db_user != ""&& $db_passwd){
	$_SESSION['db_type'] = $db_type;
	$_SESSION['db_name'] = $db_name;
	$_SESSION['db_port'] = $db_port;
	$_SESSION['db_host'] = $db_host;
	$_SESSION['db_user'] = $db_user;
	$_SESSION['db_passwd'] = $db_passwd;


	if($db_type == "pgsql"){
		$DSN = $db_type;
		$DSN .= ":host=".$db_host;
		$DSN .= " port=".$db_port;
		$DSN .= " dbname=".$db_name;
		$DSN .= " user=".$db_user;
		$DSN .= " password=".$db_passwd;

		try {
			$dbh = new PDO($DSN);

			// カラム名を小文字で取得する
			$dbh->setAttribute(PDO::ATTR_CASE, PDO::CASE_LOWER);

			// エラー時にExceptionをthrowさせる
			$dbh->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
		}
		catch (PDOException $e) {
			$mes .= 'データベースに接続できませんでした';
		}

		if($mes == ""){
			$chk = true;
			$jump = "index5.php";
		} else {
			$chk = false;
			$jump = "index4.php";
		}
	}
	if($db_type == "mysql"){
		
		$DSN = $db_type;
		$DSN .= ":dbname=".$db_name;
		$DSN .= ";port=".$db_port;
		$DSN .= ";host=".$db_host;

		try {
			$dbh = new PDO($DSN, $db_user, $db_passwd);

			// カラム名を小文字で取得する
			$dbh->setAttribute(PDO::ATTR_CASE, PDO::CASE_LOWER);

			// エラー時にExceptionをthrowさせる
			$dbh->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
		}
		catch (PDOException $e) {
			$mes .= 'データベースに接続できませんでした';
		}

		if($mes == ""){
			$chk = true;
			$jump = "index5.php";
		} else {
			$chk = false;
			$jump = "index4.php";
		}
	}
} else {

	if($db_type == ""){
		$mes .=  "データベースタイプが未入力です<br >";
	}
	if($db_name == ""){
		$mes .=  "データベース名が未入力です<br >";
	}
	if($db_port == ""){
		$mes .=  "データベース接続ポート番号が未入力です<br >";
	}
	if($db_host == ""){
		$mes .=  "データベースホスト名が未入力です<br >";
	}
	if($db_user == ""){
		$mes .=  "データベース接続ユーザー名が未入力です<br >";
	}
	if($db_passwd == ""){
		$mes .=  "データベース接続パスワードがが未入力です<br >";
	}




	$chk = false;
	$jump = "index4.php";
}

?>
<body>
<form id="setup" name="setup" method="post" action="<?php echo $jump ?>">
<table width="100%" border="0">
	<tr>
		<td height="362" valign="top">
		<div align="center">
		<p><img src="./images/cenote_logo.png" width="350" height="100" /></p>
		<p class="style1">～SETUP TOOL～</p>
		<p class="style1">３．データベース作成</p>

		<table>
		<?php
		if(isset($_POST['Submit'])){
			if($_POST['Submit'] == "確認"){
				if($mes != ""){
					echo "<tr>";
					echo "<td colspan = \"2\"><span class=\"red\">";
					echo $mes;
					echo "</span></td>";
					echo "</tr>";
				}
			}
		}
		?>
		<?php
		if( $chk ){
			echo "<tr>
          		<td class=\"con\" width=\"150\">データベースタイプ</td>
          		<td class=\"con\" width=\"250\">$db_type</td>
        		</tr>
       		 <tr>
        		<td class=\"con\">データベース名</td>
        		<td class=\"con\">$db_name</td>
       		 </tr>
       		 <tr>
        		<td class=\"con\">接続ポート番号</td>
        		<td class=\"con\">$db_port</td>
       		 </tr>
       		 <tr>
          		<td class=\"con\">DBホスト名</td>
          		<td class=\"con\">$db_host</td>
        		</tr>
       		 <tr>
          		<td class=\"con\">接続ユーザー名</td>
          		<td class=\"con\">$db_user</td>
        	 </tr>
        	 <tr>
          		<td class=\"con\">接続パスワード</td>
          		<td class=\"con\">$db_passwd</td>
        	</tr>
        	<tr>";
			echo '<td colspan="2"><div align="center"><input name="Submit" type="submit" id="Submit" value="次へ" /></div>';
		} else {
			echo "<tr>
		          <td class=\"con\" width=\"150\">データベースタイプ</td>
					<td class=\"con\" width=\"250\">	
					<select name=\"db_type\">
  						<option value=\"pgsql\" selected=\"selected\">PostgreSQL</option>
  						<option value=\"mysql\">MySQL</option>
					</select>
					</td>
		        </tr>
		        <tr>
		          <td class=\"con\">データベース名</td>
		          <td class=\"con\"><input name=\"db_name\" type=\"text\" id=\"db_name\" value=\"$db_name\" /></td>
		        </tr>
		        <tr>
		          <td class=\"con\">接続ポート番号</td>
		          <td class=\"con\"><input name=\"db_port\" type=\"text\" id=\"db_port\" value=\"$db_port\" /><br />標準はPostgreSQL=5432　MySQL=3306です</td>
		        </tr>
		        <tr>
		          <td class=\"con\">DBホスト名</td>
		          <td class=\"con\"><input name=\"db_host\" type=\"text\" id=\"db_host\" value=\"$db_host\" /></td>
		        </tr>
		        <tr>
		          <td class=\"con\">接続ユーザー名</td>
		          <td class=\"con\"><input name=\"db_user\" type=\"text\" id=\"db_user\" value=\"$db_user\" /></td>
		        </tr>
		        <tr>
		          <td class=\"con\">接続パスワード</td>
		          <td class=\"con\"><input name=\"db_passwd\" type=\"text\" id=\"db_passwd\" value=\"$db_passwd\" /></td>
		        </tr>
		        <tr>";
			echo '<td  class="con" colspan="2"><div align="center"><input name="Submit" type="submit" id="Submit" value="確認" /></div>';
		}
		?>
			</td>
			</tr>
			<p>&nbsp;</p>
			</div>
			</td>
			</tr>
		</table>
		</form>

</body>
</html>
